package # hide from PAUSE
 DBIx::Class::Schema::PopulateMore::Test::Schema::ResultSet;
 
use base 'DBIx::Class::ResultSet';

=head1 NAME

DBIx::Class::Schema::PopulateMore::Test::Schema::ResultSet - A base ResultSet Class

=head1 DESCRIPTION

All ResultSet classes will inherit from this.  This provides some base function
for all your resultsets and it is also the default resultset if you don't
bother to declare a custom resultset in the resultset namespace

=head1 PACKAGE METHODS

The following is a list of package methods declared with this class.

=head1 ATTRIBUTES

This class defines the following attributes.

=head1 METHODS

This module declares the following methods

=head1 AUTHOR

Please see L<DBIx::Class::Schema::PopulateMore> For authorship information

=head1 LICENSE

Please see L<DBIx::Class::Schema::PopulateMore> For licensing terms.

=cut


1;